@@ -12,6 +12,11 @@ def dbdraw(p:DraftingPen):
     p.cast(DrawBotPen).draw()
     return p
 
+def tobp(p:DraftingPen):
+    bp = db.BezierPath()
+    p.replay(bp)
+    return bp
+
 def dbdraw_with_filters(rect:Rect, filters):
     def _draw_call(p:DraftingPen):
         p.cast(DrawBotPen).draw_with_filters(rect, filters)
@@ -35,4 +40,21 @@ def new_drawing(rect:Rect=Rect(1000, 1000), count=1, save_to=None):
             yield idx, r
     if save_to:
         db.saveImage(str(save_to))
+    db.endDrawing()
+
+def releaser(fn, path, frame_class=None):
+    db.newDrawing()
+    r = fn.rect
+    w, h = r.wh()
+    for idx in range(0, fn.duration):
+        print(f"Saving page {idx}...")
+        db.newPage(w, h)
+        if frame_class:
+            fn.func(frame_class(idx, fn))
+        else:
+            fn.func(r)
+    pdf_path = Path(path)
+    pdf_path.parent.mkdir(exist_ok=True)
+    db.saveImage(str(pdf_path))
+    print("Saved pdf", str(pdf_path))
     db.endDrawing()
\ No newline at end of file
